"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .billingaddressfieldmode import BillingAddressFieldMode
from polar_sdk.types import BaseModel
from typing_extensions import TypedDict


class CheckoutBillingAddressFieldsTypedDict(TypedDict):
    country: BillingAddressFieldMode
    state: BillingAddressFieldMode
    city: BillingAddressFieldMode
    postal_code: BillingAddressFieldMode
    line1: BillingAddressFieldMode
    line2: BillingAddressFieldMode


class CheckoutBillingAddressFields(BaseModel):
    country: BillingAddressFieldMode

    state: BillingAddressFieldMode

    city: BillingAddressFieldMode

    postal_code: BillingAddressFieldMode

    line1: BillingAddressFieldMode

    line2: BillingAddressFieldMode
