"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .pagination import Pagination, PaginationTypedDict
from .product import Product, ProductTypedDict
from polar_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ListResourceProductTypedDict(TypedDict):
    items: List[ProductTypedDict]
    pagination: PaginationTypedDict


class ListResourceProduct(BaseModel):
    items: List[Product]

    pagination: Pagination
