"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing_extensions import TypedDict


class SubscriptionProductUpdatedMetadataTypedDict(TypedDict):
    subscription_id: str
    old_product_id: str
    new_product_id: str


class SubscriptionProductUpdatedMetadata(BaseModel):
    subscription_id: str

    old_product_id: str

    new_product_id: str
