"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .addressinput import AddressInput, AddressInputTypedDict
from .taxidformat import TaxIDFormat
from polar_sdk.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Dict, List, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


CustomerUpdateExternalIDMetadataTypedDict = TypeAliasType(
    "CustomerUpdateExternalIDMetadataTypedDict", Union[str, int, float, bool]
)


CustomerUpdateExternalIDMetadata = TypeAliasType(
    "CustomerUpdateExternalIDMetadata", Union[str, int, float, bool]
)


CustomerUpdateExternalIDTaxIDTypedDict = TypeAliasType(
    "CustomerUpdateExternalIDTaxIDTypedDict", Union[str, TaxIDFormat]
)


CustomerUpdateExternalIDTaxID = TypeAliasType(
    "CustomerUpdateExternalIDTaxID", Union[str, TaxIDFormat]
)


class CustomerUpdateExternalIDTypedDict(TypedDict):
    metadata: NotRequired[Dict[str, CustomerUpdateExternalIDMetadataTypedDict]]
    r"""Key-value object allowing you to store additional information.

    The key must be a string with a maximum length of **40 characters**.
    The value must be either:

    * A string with a maximum length of **500 characters**
    * An integer
    * A floating-point number
    * A boolean

    You can store up to **50 key-value pairs**.
    """
    email: NotRequired[Nullable[str]]
    r"""The email address of the customer. This must be unique within the organization."""
    name: NotRequired[Nullable[str]]
    r"""The name of the customer."""
    billing_address: NotRequired[Nullable[AddressInputTypedDict]]
    tax_id: NotRequired[
        Nullable[List[Nullable[CustomerUpdateExternalIDTaxIDTypedDict]]]
    ]


class CustomerUpdateExternalID(BaseModel):
    metadata: Optional[Dict[str, CustomerUpdateExternalIDMetadata]] = None
    r"""Key-value object allowing you to store additional information.

    The key must be a string with a maximum length of **40 characters**.
    The value must be either:

    * A string with a maximum length of **500 characters**
    * An integer
    * A floating-point number
    * A boolean

    You can store up to **50 key-value pairs**.
    """

    email: OptionalNullable[str] = UNSET
    r"""The email address of the customer. This must be unique within the organization."""

    name: OptionalNullable[str] = UNSET
    r"""The name of the customer."""

    billing_address: OptionalNullable[AddressInput] = UNSET

    tax_id: OptionalNullable[List[Nullable[CustomerUpdateExternalIDTaxID]]] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["metadata", "email", "name", "billing_address", "tax_id"]
        nullable_fields = ["email", "name", "billing_address", "tax_id"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
