"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing_extensions import TypedDict


class BenefitGrantErrorTypedDict(TypedDict):
    message: str
    type: str
    timestamp: str


class BenefitGrantError(BaseModel):
    message: str

    type: str

    timestamp: str
